@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Free42 -- an HP-42S calculator simulator
- * Copyright (C) 2004-2024  Thomas Okken
+ * Copyright (C) 2004-2025  Thomas Okken
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -437,45 +437,48 @@
 #define CMD_PUTMI       391
 #define CMD_GETLI       392
 #define CMD_PUTLI       393
+#define CMD_LOCK        394
+#define CMD_UNLOCK      395
+#define CMD_IDENT       396
 /* String & List Functions */
-#define CMD_XSTR        394
-#define CMD_XASTO       395
-#define CMD_LXASTO      396
-#define CMD_XVIEW       397
-#define CMD_APPEND      398
-#define CMD_EXTEND      399
-#define CMD_SUBSTR      400
-#define CMD_LENGTH      401
-#define CMD_HEAD        402
-#define CMD_REV         403
-#define CMD_POS         404
-#define CMD_S_TO_N      405
-#define CMD_N_TO_S      406
-#define CMD_NN_TO_S     407
-#define CMD_C_TO_N      408
-#define CMD_N_TO_C      409
-#define CMD_LIST_T      410
-#define CMD_NEWLIST     411
-#define CMD_TO_LIST     412
-#define CMD_FROM_LIST   413
+#define CMD_XSTR        397
+#define CMD_XASTO       398
+#define CMD_LXASTO      399
+#define CMD_XVIEW       400
+#define CMD_APPEND      401
+#define CMD_EXTEND      402
+#define CMD_SUBSTR      403
+#define CMD_LENGTH      404
+#define CMD_HEAD        405
+#define CMD_REV         406
+#define CMD_POS         407
+#define CMD_S_TO_N      408
+#define CMD_N_TO_S      409
+#define CMD_NN_TO_S     410
+#define CMD_C_TO_N      411
+#define CMD_N_TO_C      412
+#define CMD_LIST_T      413
+#define CMD_NEWLIST     414
+#define CMD_TO_LIST     415
+#define CMD_FROM_LIST   416
 /* Generalized Comparisons */
-#define CMD_X_EQ_NN     414
-#define CMD_X_NE_NN     415
-#define CMD_X_LT_NN     416
-#define CMD_X_GT_NN     417
-#define CMD_X_LE_NN     418
-#define CMD_X_GE_NN     419
-#define CMD_0_EQ_NN     420
-#define CMD_0_NE_NN     421
-#define CMD_0_LT_NN     422
-#define CMD_0_GT_NN     423
-#define CMD_0_LE_NN     424
-#define CMD_0_GE_NN     425
+#define CMD_X_EQ_NN     417
+#define CMD_X_NE_NN     418
+#define CMD_X_LT_NN     419
+#define CMD_X_GT_NN     420
+#define CMD_X_LE_NN     421
+#define CMD_X_GE_NN     422
+#define CMD_0_EQ_NN     423
+#define CMD_0_NE_NN     424
+#define CMD_0_LT_NN     425
+#define CMD_0_GT_NN     426
+#define CMD_0_LE_NN     427
+#define CMD_0_GE_NN     428
 /* For Plus42 compatibility */
-#define CMD_WIDTH       426
-#define CMD_HEIGHT      427
+#define CMD_WIDTH       429
+#define CMD_HEIGHT      430
 
-#define CMD_SENTINEL    428
+#define CMD_SENTINEL    431
 
 
 /* command_spec.argtype */
